from modules.python.PairwiseAlignment import PairWiseAlignment

a = PairWiseAlignment()
ref = "TAGTATATACACTATACTATATACTAGTGTATTATACTAGTATATACACTATACTATATACTAGTGTATTATACTAGTATATACACTATACTATATACTAGTGTATATACTAGTATATAC"
query = "TATACTAGTGTATTATACTAGTATAATACACTATACTATATACTAGTGTATTATACTAGTATATACACTATACTATATGCTAGTGTATTATACTAGTATATACACTATACTATATACTAG"

a.perform_pairwise_alignment(ref, query)